# pytelechat



Telegram chat data receiver package

### Install package

```bash
pip install pytelechat
```

### Use
```python
from pytelechat import Chat

chat = Chat('https://t.me/djangouzbekcommunity')

print(chat.data)
```
#### Developed by Quvonchbek Bobojonov (c) 2023